==> activity-center-api-1.7.23.2-20170928.032711-1-sources.jar: cn/com/duiba/activity/center/api/enums/ActivityDataTypeEnum.java <==
package cn.com.duiba.activity.center.api.enums;

import java.util.List;
import java.util.Map;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;

/** 
 * ClassName:ActivityDataTypeEnum.java <br/>
 * @author  gey 
 * @date 创建时间：2017年7月19日 下午4:18:59 
 * @version 1.0 
 * @parameter  
 * @since   JDK 1.6
 */
public enum ActivityDataTypeEnum {
	
	ACTIVITY_TOOL("hdtool","概率出奖",false),
	QUESTION_ANSWER("question","答题活动-题目数出奖",true),
	QUESTION_ANSWER_HDTOOL("qhdtool","答题活动-概率出奖",true),
	THROUGH("through","闯关游戏",true);
	
	//后续操作key
	private String key;
	//名称
	private String name;
	//是否执行 后续操作  true 不执行，false 执行
	private boolean executeFlag;
	private static Map<String,ActivityDataTypeEnum> typeMap = Maps.newHashMap();
	private static List<ActivityDataTypeEnum> list =Lists.newArrayList();
	
	ActivityDataTypeEnum(String key,String name,boolean executeFlag){
		this.name = name;
		this.key = key;
		this.executeFlag = executeFlag;
	}

	public String getKey() {
		return key;
	}

	public String getName() {
		return name;
	}

	public boolean isExecuteFlag() {
		return executeFlag;
	}

	static{
		for(ActivityDataTypeEnum typeClass : ActivityDataTypeEnum.values()){
			typeMap.put(typeClass.getKey(),typeClass);
			list.add(typeClass);
		}
	}

	/**
	 * 根据type获取具体枚举类型
	 * @param type
	 * @return
	 */
	public static ActivityDataTypeEnum getByType(String key){
		return typeMap.get(key);
	}
	
	/**
	 * 获取全部 枚举值和名称
	 * @param type
	 * @return
	 */
	public static List<ActivityDataTypeEnum> getAll(){
		return list;
	}
}

==> activity-center-api-3.4.6-sources.jar: cn/com/duiba/activity/center/api/enums/ActivityDataTypeEnum.java <==
package cn.com.duiba.activity.center.api.enums;

import java.util.List;
import java.util.Map;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;

/** 
 * ClassName:ActivityDataTypeEnum.java <br/>
 * @author  gey 
 * @date 创建时间：2017年7月19日 下午4:18:59 
 * @version 1.0 
 * @parameter  
 * @since   JDK 1.6
 */
public enum ActivityDataTypeEnum {
	
	ACTIVITY_TOOL("hdtool","概率出奖",false),
	QUESTION_ANSWER("question","答题活动-题目数出奖",true),
	QUESTION_ANSWER_HDTOOL("qhdtool","答题活动-概率出奖",true),
	GUESS_TOOL("guess","竞猜",false),
	GAME_TOOL("game","游戏前置开奖",false),
	THROUGH("through","闯关游戏",true);
	
	//后续操作key
	private String key;
	//名称
	private String name;
	//是否执行 后续操作  true 不执行，false 执行
	private boolean executeFlag;
	private static Map<String,ActivityDataTypeEnum> typeMap = Maps.newHashMap();
	private static List<ActivityDataTypeEnum> list =Lists.newArrayList();
	
	ActivityDataTypeEnum(String key,String name,boolean executeFlag){
		this.name = name;
		this.key = key;
		this.executeFlag = executeFlag;
	}

	public String getKey() {
		return key;
	}

	public String getName() {
		return name;
	}

	public boolean isExecuteFlag() {
		return executeFlag;
	}

	static{
		for(ActivityDataTypeEnum typeClass : ActivityDataTypeEnum.values()){
			typeMap.put(typeClass.getKey(),typeClass);
			list.add(typeClass);
		}
	}

	/**
	 * 根据type获取具体枚举类型
	 * @param key
	 * @return
	 */
	public static ActivityDataTypeEnum getByType(String key){
		return typeMap.get(key);
	}
	
	/**
	 * 获取全部 枚举值和名称
	 * @return
	 */
	public static List<ActivityDataTypeEnum> getAll(){
		return list;
	}
}
